@@ -15,7 +15,12 @@
 #
 # ##### END GPL LICENSE BLOCK #####
 
-from .modules import general
-from .modules import mathutils
-from .modules import pygame
-from .modules import socket
\ No newline at end of file
+from . import pygameutils
+from . import algorithms
+from . import mathlib
+
+print("""Python module PumpkinPy
+Owner: Spatial Innovations <https://github.com/Spatial-Innovations>
+Contributors:
+    Patrick Huang <https://github.com/HuangPatrick16777216>
+    Arjun Sahlot <https://github.com/ArjunSahlot>""")
\ No newline at end of file
